@@ -15,4 +15,4 @@ def get_decode_sink():
     except Exception:
         log.warning("DB unavailable, using file-only decode sink")
 
-    return MultiSink(*sinks)
+    return MultiSink(*sinks) or return_all_datas()
