@@ -4,15 +4,15 @@ from abstract_security import get_env_value
 from abstract_apis import get_headers,get_response
 import requests
 solana_rpc_url="http://api.mainnet-beta.solana.com"
-fall_back_rpc = get_env_value('solana_fallback_rpc_url')
+fall_back_rpc = get_env_value('SOLANA_FALLBACK_RPC_URL')
 def getSolcatcherUrl(endpoint=None):
   return getEndpointUrl(endpoint=endpoint,url='https://solcatcher.io')
 def getSolcatcherPairCatchUrl(endpoint=None):
-  return getEndpointUrl(endpoint=endpoint,url='https://solcatcher.io/pairCatch')
+  return getEndpointUrl(endpoint=endpoint,url='https://solcatcher.io/api')
 def getSolcatcherTsUrl(endpoint=None):
-  return getEndpointUrl(endpoint=endpoint,url='https://solcatcher.io/ts')
+  return getEndpointUrl(endpoint=endpoint,url='https://solcatcher.io/ts-api')
 def getSolcatcherDbCalls(endpoint=None):
-  return getEndpointUrl(endpoint=endpoint,url="https://solcatcher.io/dbCalls")
+  return getEndpointUrl(endpoint=endpoint,url="https://solcatcher.io/api")
 def get_response(response):
     if isinstance(response,requests.Response) or isinstance(response,httpx.Response):
       try:
